@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: debug.c,v 1.13 2003/09/15 18:57:33 nalin Exp $"
+#ident "$Id: debug.c,v 1.14 2006/02/03 13:27:26 behdad Exp $"
 #include "../config.h"
 #include <glib.h>
 #include <stdio.h>
@@ -74,6 +74,9 @@ _vte_debug_parse_string(const char *string)
 			} else
 			if (g_ascii_strcasecmp(flags[i], "LIFECYCLE") == 0) {
 				_vte_debug_flags |= VTE_DEBUG_LIFECYCLE;
+			} else
+			if (g_ascii_strcasecmp(flags[i], "TRIE") == 0) {
+				_vte_debug_flags |= VTE_DEBUG_TRIE;
 			}
 		}
 		g_strfreev(flags);
